@@ -37,8 +37,8 @@
 /*lint -save -e525 -e539 -e835 */
 
 /*--------------------------------------------------------------------
- *  * Simple parameters
- *   */
+ * Simple parameters
+ */
 
 #define PARAM_SIMPLE(nm, typ, ...) \
 	PARAM(typ, nm, nm, tweak_##typ, &mgt_param.nm, __VA_ARGS__)
@@ -325,7 +325,7 @@ PARAM_SIMPLE(
 	/* def */	"60.000",
 	/* units */	"seconds",
 	/* descr */
-	"Timeout for the childs replies to CLI requests from the "
+	"Timeout for the child's replies to CLI requests from the "
 	"mgt_param."
 )
 
@@ -855,7 +855,7 @@ PARAM_SIMPLE(
 	/* name */	tcp_keepalive_intvl,
 	/* type */	timeout,
 	/* min */	"1",
-	/* max */	"100",
+	/* max */	"150",
 	/* def */	NULL,
 	/* units */	"seconds",
 	/* descr */
@@ -888,7 +888,7 @@ PARAM_SIMPLE(
 	/* name */	tcp_keepalive_time,
 	/* type */	timeout,
 	/* min */	"1",
-	/* max */	"7200",
+	/* max */	"14400",
 	/* def */	NULL,
 	/* units */	"seconds",
 	/* descr */
@@ -1021,7 +1021,7 @@ PARAM_SIMPLE(
 	/* name */	vsl_reclen,
 	/* type */	vsl_reclen,
 	/* min */	"16b",
-	/* max */	NULL,
+	/* max */	"65535b",	// VSL_LENMASK
 	/* def */	"255b",
 	/* units */	"bytes",
 	/* descr */
@@ -1046,18 +1046,6 @@ PARAM_SIMPLE(
 	/* flags */	MUST_RESTART
 )
 
-PARAM_SIMPLE(
-	/* name */	vsm_space,
-	/* type */	bytes,
-	/* min */	"1M",
-	/* max */	"1G",
-	/* def */	"1M",
-	/* units */	"bytes",
-	/* descr */
-	"DEPRECATED: This parameter is ignored.\n"
-	"There is no global limit on amount of shared memory now."
-)
-
 PARAM_SIMPLE(
 	/* name */	workspace_backend,
 	/* type */	bytes_u,
@@ -1179,7 +1167,8 @@ PARAM_SIMPLE(
 /* We have a strict min at the protocol default here. This is because we
  * don't have the 'use settings only after peer ack' in place yet. If the
  * value is lower than the protocol default, the very first stream could
- * get a flow control error. */
+ * get a flow control error.
+ */
 PARAM_SIMPLE(
 	/* name */	h2_initial_window_size,
 	/* type */	bytes_u,
@@ -1541,11 +1530,42 @@ PARAM_STRING(
 	/* priv */	&mgt_cc_cmd,
 	/* def */	VCC_CC,
 	/* descr */
-	"Command used for compiling the C source code to a "
-	"dlopen(3) loadable object.  Any occurrence of %s in "
-	"the string will be replaced with the source file name, "
-	"and %o will be replaced with the output file name.",
-	/* flags */	MUST_RELOAD
+	"The command used for compiling the C source code to a "
+	"dlopen(3) loadable object. The following expansions can "
+	"be used:\n\n"
+	"- %s: the source file name\n"
+	"- %o: the output file name\n"
+	"- %w: the cc_warnings parameter\n"
+	"- %d: the raw default cc_command\n"
+	"- %D: the expanded default cc_command\n"
+	"- %n: the working directory (-n option)\n"
+	"- %%: a percent sign\n"
+	"\n"
+	"Unknown percent expansion sequences are ignored, and to "
+	"avoid future incompatibilities percent characters should "
+	"be escaped with a double percent sequence.\n\n"
+	"The %d and %D expansions allow passing the parameter's "
+	"default value to a wrapper script to perform additional "
+	"processing.",
+	/* flags */	MUST_RELOAD | BUILD_OPTIONS,
+	/* dyn_min_reason */	NULL,
+	/* dyn_max_reason */	NULL,
+	/* dyn_def_reason */	"exec $CC $CFLAGS %w -shared -o %o %s"
+)
+
+PARAM_STRING(
+	/* name */	cc_warnings,
+	/* tweak */	tweak_string,
+	/* priv */	&mgt_cc_warn,
+	/* def */	VCC_WARN,
+	/* descr */
+	"Warnings used when compiling the C source code with "
+	"the cc_command parameter. By default, VCL is compiled "
+	"with the same set of warnings as Varnish itself.",
+	/* flags */	MUST_RELOAD | BUILD_OPTIONS,
+	/* dyn_min_reason */	NULL,
+	/* dyn_max_reason */	NULL,
+	/* dyn_def_reason */	"-Wall -Werror"
 )
 
 PARAM_STRING(
@@ -1571,7 +1591,11 @@ PARAM_STRING(
 	"VCL files in both the system configuration and shared "
 	"data directories to allow packages to drop their VCL "
 	"files in a standard location where relative includes "
-	"would work."
+	"would work.",
+	/* flags */	BUILD_OPTIONS,
+	/* dyn_min_reason */	NULL,
+	/* dyn_max_reason */	NULL,
+	/* dyn_def_reason */	"${sysconfdir}/varnish:${datadir}/varnish/vcl"
 )
 
 PARAM_STRING(
@@ -1581,7 +1605,11 @@ PARAM_STRING(
 	/* def */	VARNISH_VMOD_DIR,
 	/* descr */
 	"Directory (or colon separated list of directories) "
-	"where VMODs are to be found."
+	"where VMODs are to be found.",
+	/* flags */	BUILD_OPTIONS,
+	/* dyn_min_reason */	NULL,
+	/* dyn_max_reason */	NULL,
+	/* dyn_def_reason */	"${libdir}/varnish/vmods"
 )
 
 /*--------------------------------------------------------------------
@@ -1652,6 +1680,23 @@ PARAM_PCRE2(
 	" messages."
 )
 
+/*--------------------------------------------------------------------
+ * Parameter deprecated aliases
+ *
+ * When a parameter is renamed, but a deprecated alias is kept for
+ * compatibility, its documentation is minimal: only a description in
+ * manual pages, a description and current value in the CLI.
+ *
+ * The deprecated_dummy alias is here for test coverage.
+ */
+
+#define PARAM_ALIAS(al, nm) \
+	PARAM(, , al, tweak_alias, NULL, NULL, NULL, #nm, NULL, \
+	    "Deprecated alias for the " #nm " parameter.")
+
+PARAM_ALIAS(deprecated_dummy, debug)
+
+#  undef PARAM_ALIAS
 #  undef PARAM_ALL
 #  undef PARAM_PCRE2
 #  undef PARAM_STRING
@@ -1691,6 +1736,23 @@ PARAM(
 	"	vtc_mode	Varnishtest Mode"
 )
 
+/* actual location mgt_param_bits.c*/
+/* see tbl/experimental_bits.h */
+PARAM(
+	/* name */	experimental,
+	/* type */	experimental,
+	/* min */	NULL,
+	/* max */	NULL,
+	/* def */	NULL,
+	/* units */	NULL,
+	/* descr */
+	"Enable/Disable experimental features.\n"
+	"	none	Disable all experimental features\n"
+	"\n"
+	"Use +/- prefix to set/reset individual bits:\n"
+	"	drop_pools	Drop thread pools\n"
+)
+
 /* actual location mgt_param_bits.c*/
 /* See tbl/feature_bits.h */
 PARAM(
